==> cxf-bundle-jaxrs-2.3.5-fuse-01-26-sources.jar: org/apache/cxf/endpoint/ServerLifeCycleManagerImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.endpoint;

import java.util.List;

import java.util.concurrent.CopyOnWriteArrayList;

import org.apache.cxf.common.injection.NoJSR250Annotations;
import org.apache.cxf.extension.BusExtension;

@NoJSR250Annotations
public class ServerLifeCycleManagerImpl implements ServerLifeCycleManager, BusExtension {
    
    private List<ServerLifeCycleListener> listeners = 
            new CopyOnWriteArrayList<ServerLifeCycleListener>();

    public Class<?> getRegistrationType() {
        return ServerLifeCycleManager.class;
    }

    public synchronized void registerListener(ServerLifeCycleListener listener) {
        listeners.add(listener);
    }

    public void startServer(Server server) {
        for (ServerLifeCycleListener listener : listeners) {
            listener.startServer(server);
        }
    }

    public void stopServer(Server server) {
        for (ServerLifeCycleListener listener : listeners) {
            listener.stopServer(server);
        }
    }

    public synchronized void unRegisterListener(ServerLifeCycleListener listener) {
        listeners.remove(listener);
    }
}

==> cxf-bundle-jaxrs-2.4.3-fuse-04-15-sources.jar: org/apache/cxf/endpoint/ServerLifeCycleManagerImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.endpoint;

import java.util.Collection;

import java.util.concurrent.CopyOnWriteArrayList;

import org.apache.cxf.Bus;
import org.apache.cxf.common.injection.NoJSR250Annotations;
import org.apache.cxf.configuration.ConfiguredBeanLocator;
import org.apache.cxf.extension.BusExtension;

@NoJSR250Annotations
public class ServerLifeCycleManagerImpl implements ServerLifeCycleManager, BusExtension {
    
    private CopyOnWriteArrayList<ServerLifeCycleListener> listeners = 
            new CopyOnWriteArrayList<ServerLifeCycleListener>();

    public ServerLifeCycleManagerImpl() {
        
    }
    public ServerLifeCycleManagerImpl(Bus b) {
        Collection<? extends ServerLifeCycleListener> l = b.getExtension(ConfiguredBeanLocator.class)
                .getBeansOfType(ServerLifeCycleListener.class);
        if (l != null) {
            listeners.addAll(l);
        }
    }
    public Class<?> getRegistrationType() {
        return ServerLifeCycleManager.class;
    }

    
    public synchronized void registerListener(ServerLifeCycleListener listener) {
        listeners.addIfAbsent(listener);
    }

    public void startServer(Server server) {
        for (ServerLifeCycleListener listener : listeners) {
            listener.startServer(server);
        }
    }

    public void stopServer(Server server) {
        for (ServerLifeCycleListener listener : listeners) {
            listener.stopServer(server);
        }
    }

    public synchronized void unRegisterListener(ServerLifeCycleListener listener) {
        listeners.remove(listener);
    }
}
